@@ -31,13 +31,19 @@ docnames.default <- function(x) {
 #' @noRd
 #' @export
 docnames.corpus <- function(x) {
-    # didn't use accessor documents() because didn't want to pass
-    # that large object
-    if (is.null(rownames(x$documents))) {
-        paste0("text", seq_len(ndoc(x)))
+    if (is_pre2(x)) {
+        # didn't use accessor documents() because didn't want to pass
+        # that large object
+        result <- if (is.null(rownames(x$documents))) {
+            paste0("text", seq_len(ndoc(x)))
+        } else {
+            rownames(x$documents)
+        }
     } else {
-        rownames(x$documents)
+        result <- docnamesv2.corpus(x)
     }
+    
+    result
 }
 
 #' @param value a character vector of the same length as \code{x}
@@ -62,6 +68,7 @@ docnames.corpus <- function(x) {
 #' @noRd
 #' @export
 "docnames<-.corpus" <- function(x, value) {
+    x <- corpus(x)
     docvars(x, "_document") <- rownames(x$documents) <- as.character(value)
     return(x)
 }
