@@ -30,10 +30,16 @@ docvars.default <- function(x, field = NULL) {
 #' @export
 docvars.corpus <- function(x, field = NULL) {
     check_fields(x, field)
-    dvars <- documents(x)[, which(names(documents(x)) != "texts"), drop = FALSE]
-    if (is.null(field))
-        dvars <- dvars[, which(substring(names(dvars), 1, 1) != "_"), drop = FALSE]
-    get_docvars(dvars, field)
+    if (is_pre2(x)) {
+        dvars <- documents(x)[, which(names(documents(x)) != "texts"), drop = FALSE]
+        if (is.null(field))
+            dvars <- dvars[, which(substring(names(dvars), 1, 1) != "_"), drop = FALSE]
+        return(get_docvars(dvars, field))
+    } else {
+        dvars <- docvarsv2.corpus(x)
+        rownames(dvars) <- docnamesv2.corpus(x)
+        return(dvars)
+    }
 }
 
 #' @noRd
@@ -99,6 +105,7 @@ docvars.kwic <- function(x) {
 
 #' @export
 "docvars<-.corpus" <- function(x, field = NULL, value) {
+    x <- corpus(x)
     x$documents <- set_docvars(x$documents, field, value)
     return(x)
 }
@@ -159,6 +166,7 @@ metadoc.default <- function(x, field = NULL) {
 #' @noRd
 #' @export
 metadoc.corpus <- function(x, field = NULL) {
+    x <- corpus(x)
     if (!is.null(field)) {
         field <- paste0("_", field)
         check_fields(x, field)
@@ -204,6 +212,7 @@ metadoc.dfm <- function(x, field = NULL) {
 #' @noRd
 #' @export
 "metadoc<-.corpus" <- function(x, field = NULL, value) {
+    x <- corpus(x)
     # CHECK TO SEE THAT VALUE LIST IS IN VALID DOCUMENT-LEVEL METADATA LIST
     # (this check not yet implemented)
     if (is.null(field)) {
