@@ -65,7 +65,7 @@
 #'   
 #' @references 
 #'   Momtazi, S., Khudanpur, S., & Klakow, D. (2010). 
-#'   "\href{https://www.lsv.uni-saarland.de/fileadmin/publications/SaeedehMomtazi-HLT_NAACL10.pdf}{A
+#'   "\href{https://www.aclweb.org/anthology/N10-1046/}{A
 #'    comparative study of word co-occurrence for term clustering in language 
 #'   model-based sentence retrieval.}" \emph{Human Language Technologies: The 
 #'   2010 Annual Conference of the North American Chapter of the ACL}, Los 
@@ -234,7 +234,7 @@ fcm.tokens <- function(x, context = c("document", "window"),
         # create a new feature context matrix
         result <- new("fcm", as(result, "dgCMatrix"), count = count,
                       context = context, window = window, margin = colSums(dfm(x)),
-                      weights = weights, tri = tri)
+                      weights = weights, tri = tri, ordered = ordered)
     }
     return(result)
 }     
