@@ -19,4 +19,11 @@ test_that("friendly_class_undefined_message for char_tortl()", {
         char_tortl(data_dfm_lbgexample),
         "char_tortl\\(\\) only works on.*character.*objects"
     )
-})
\ No newline at end of file
+})
+
+test_that("friendly_class_undefined_message for featfreq()", {
+    expect_error(
+        featfreq(tokens(data_char_sampletext)),
+        "featfreq\\(\\) only works on dfm objects"
+    )
+})
